/**=================================================================================================
Hochschule Luzern - Technik & Architektur                                   Mikrocontroller - HS2012
Copyright 2012 Felix Rohrer                                                     http://hslu.ximit.ch
----------------------------------------------------------------------------------------------------
Project     : Adressverwaltung
Name        : addressFileIO.h
Author      : Felix Rohrer <felix.rohrer@stud.hslu.ch>
Version     : 2012-10-19v1.0
Description : Adressverwaltung
              Adressen in eine Datei (csv) speichern oder aus einer Datei importieren.
==================================================================================================*/
#ifndef ADDRESSFILEIO_H
#define	ADDRESSFILEIO_H

/**
 * Parse the line to get the Address Details
 * @param line Addres Line from CSV Export
 * @return Success / Error Status Code
 */
err_t lineParser(char* line);

/**
 * Export AddressList to a CSV_File
 * @param path Filepath, Filename for the csv-File
 * @param addrList Pointer to the current AddressList
 * @param formatCSVfn CallBack-Function to format the Output
 * @param num Return value how many Addresses are exporet
 * @return Success / Error Status Code
 */
err_t writeFile(char* path, addressList_t* addrList, err_t (*formatCSVfn)(address_t*, char*), int* num);

/**
 * Import AddressList from a CSV-File
 * @param path Filepath, Filename for the csv-File
 * @param addrList Pointer to the current AddressList
 * @param lineParserFn CallBack-Function for the LineParser (Format)
 * @param num Returnh value how many Addresses are imported
 * @return Success / Error Status Code
 */
err_t readFile(char* path, addressList_t* addrList, err_t (*lineParserFn)(char*), int* num);

/**
 * CallBack-Function to Format the Export: CSV by Tab
 * @param addr Pointer to one Address
 * @param line Formated Output String
 * @return Success / Error Status Code
 */
err_t formatCSVTab(address_t* addr, char* line);

/**
 * CallBack-Function to Format the Export: CSV by Semicolon
 * @param addr Pointer to one Address
 * @param line Formated Output String
 * @return Success / Error Status Code
 */
err_t formatCSVSemicolon(address_t* addr, char* line);

#endif	/* ADDRESSFILEIO_H */
